
package ${packageName};

import javax.ws.rs.Consumes;
import javax.ws.rs.Produces;
import javax.ws.rs.DELETE;
import javax.ws.rs.core.UriInfo;
import javax.ws.rs.Produces;
import javax.ws.rs.GET;
import javax.ws.rs.PUT;
import javax.ws.rs.POST;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.DefaultValue;

import com.sun.mep.connector.jaxrs.getbusinessobjects.BusinessObjects;

/**
 * Resource that implements CUD operations.
 */
public class MyBusinessObjectResource {
    
    private UriInfo context;

    public MyBusinessObjectResource(UriInfo context) {
        this.context = context;
    }

    /**
     * Returns a binary representation of a business object. The
     * binary representation is part of the contract between a
     * connector and a client.
     * 
     * @param user  User's name logged into the session
     * @param password  User's password logged into the session
     * @param sessionId  Sync session id generated by gateway
     * @param id  Business object's identifier
     * @return  Binary representation of business object
     */
    @GET
    @Produces("application/octet-stream")
    public byte[] getBusinessObject(
            @QueryParam("username") @DefaultValue("username") String user,
            @QueryParam("password") @DefaultValue("password") String password,
            @QueryParam("sessionId") @DefaultValue("") String sessionId,
            @PathParam("id") String id) 
    {
        // INSERT CODE: return object representation for client
        return new byte[0];
    }
    
    /**
     * Creates or updates the binary representation of a business object. 
     * If the object's id does not exist, a new instance must be
     * created in the back-end system; othewise, the existing instance
     * must be updated. The binary representation in the payload received
     * is defined by the contract between a connector and a MEP client.
     * 
     * @param user  User's name logged into the session
     * @param password  User's password logged into the session
     * @param sessionId  Sync session id generated by gateway
     * @param lastModified  Last modified timestamp in millis from epoch
     * @param id  Business object's identifier
     */
    @PUT
    @Consumes("application/octet-stream")
    public void putBusinessObject(
            @QueryParam("username") @DefaultValue("username") String user,
            @QueryParam("password") @DefaultValue("password") String password,
            @QueryParam("sessionId") @DefaultValue("") String sessionId,
            @QueryParam("lastModified") @DefaultValue("0") long lastModified,
            @PathParam("id") String id, byte[] object) 
    {
        // INSERT CODE: create/update object from client
    }
    
    /**
     * Deletes a business object from the back-end system. The 
     * binary representation in the payload received is defined 
     * by the contract between a connector and a MEP client.
     * 
     * @param user  User's name logged into the session
     * @param password  User's password logged into the session
     * @param sessionId  Sync session id generated by gateway
     * @param lastModified  Last modified timestamp in millis from epoch
     * @param id  Business object's identifier
     */
    @DELETE
    public void deleteBusinessObject(
            @QueryParam("username") @DefaultValue("username") String user,
            @QueryParam("password") @DefaultValue("password") String password,
            @QueryParam("sessionId") @DefaultValue("") String sessionId,
            @QueryParam("lastModified") @DefaultValue("0") long lastModified,
            @PathParam("id") String id, byte[] object) 
    {
        // INSERT CODE: delete object
    }
    
    /**
     * This method is called to resolve an update conflict. A
     * connector is responsible for merging a server object
     * and a client object and returning the binary representation
     * of the result.
     * 
     * @param user  User's name logged into the session
     * @param password  User's password logged into the session
     * @param sessionId  Sync session id generated by gateway
     * @param id  Business object's identifier
     * @param objects  JAXB bean containing both objects, where
     *     <tt>serverObject</tt> is in entry 0 and <tt>clientObject</tt> in
     *     entry 1 of list returned by <tt>objects.getBusinessObject()</tt>.
     * @return  Binary represenation of merged object
     */
    @POST
    @Produces("application/octet-stream")
    public byte[] mergeBusinessObjects(
            @QueryParam("username") @DefaultValue("username") String user,
            @QueryParam("password") @DefaultValue("password") String password,
            @QueryParam("sessionId") @DefaultValue("") String sessionId,
            @PathParam("id") String id, BusinessObjects objects) 
    {
        // INSERT CODE: merge entries 0 and 1 in objects.getBusinessObject()
        return null;
    }
    
}
