
package ${packageName};

import java.io.ByteArrayOutputStream;
import java.util.List;
import javax.xml.bind.Marshaller;

import javax.ws.rs.core.Context;
import javax.ws.rs.core.UriInfo;
import javax.ws.rs.Produces;
import javax.ws.rs.Path;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PathParam;
import javax.ws.rs.QueryParam;
import javax.ws.rs.DefaultValue;

import com.sun.mep.connector.jaxrs.getbusinessobjects.BusinessObjectContext;
import com.sun.mep.connector.jaxrs.getbusinessobjects.BusinessObject;
import com.sun.mep.connector.jaxrs.getbusinessobjects.BusinessObjects;

/**
 * This resource class exposes the following URLs:
 * 
 * GET or POST to:
 * http://server:port/context-root/resources/businessObjects
 * 
 * GET, PUT, DELETE, POST to:
 * http://server:port/context-root/resources/businessObjects/{id}
 *
 */
@Path("businessObjects")
public class MyBusinessObjectsResource {
    
    // UPDATE CODE: Set extension for these objects
    public static final String EXTENSION = ".obj";
    
    @Context
    private UriInfo context;
    
    public MyBusinessObjectsResource() {
    }

    /**
     * This is a lifecycle method that is used to initialize and
     * terminate a session with the JAX-RS connector bridge. 
     * For convenience, this method returns the extension used
     * by the business objects returned by this connector.
     * 
     * @param user  User's name logged into the session
     * @param password  User's password logged into the session
     * @param sessionId  Sync session id generated by gateway
     * @param operation  Operation to be carried out
     * @return  Business object extension
     */
    @POST
    @Produces("text/plain")
    public String lifeCycle(
            @QueryParam("username") @DefaultValue("username") String user,
            @QueryParam("password") @DefaultValue("password") String password,
            @QueryParam("sessionId") @DefaultValue("") String sessionId,
            @QueryParam("operation") String operation) 
    {
        if (operation.equals("initialize")) {
            // INSERT CODE: session initialization
        }
        else if (operation.equals("terminate")) {
            // INSERT CODE: session termination
        }
        else {
            throw new RuntimeException("Lifecycle operation " + operation + 
                    " not understood");
        }
        return EXTENSION;
    }
    
    /**
     * Returns a JAXB bean that holds a list of all the business
     * objects available in the back-end system.
     * 
     * @param user  User's name logged into the session
     * @param password  User's password logged into the session
     * @param sessionId  Sync session id generated by gateway
     * @return  JAXB bean to be serialized
     */
    @GET
    @Produces("text/xml")
    public BusinessObjects getBusinessObjects(
            @QueryParam("username") @DefaultValue("username") String user,
            @QueryParam("password") @DefaultValue("password") String password,
            @QueryParam("sessionId") @DefaultValue("") String sessionId) 
    {
        try {
            BusinessObjects result = new BusinessObjects();
            List<BusinessObject> resultList = result.getBusinessObject();
            
            // INSERT CODE: populate list of business objects
            
            return result;
        }
        catch (Exception e) {
            throw new RuntimeException(e); 
        }
    }

    /**
     * Provides access to each business object using its id.
     * 
     * @param id  Business object identifier
     */
    @Path("{id}")
    public MyBusinessObjectResource getBusinessObject(@PathParam("id") String id) {
        return new MyBusinessObjectResource(context);
    }
    
}
